-
- {/* 移动端折叠菜单 */}
-
-
- collapseRef.current?.updateCollapseHeight(param)} />
-
-
-
- {/* 导航栏菜单 */}
-
-
- {/* 左侧图标Logo */}
-
-
- {/* 折叠按钮、仅移动端显示 */}
-
-
- {/* 桌面端顶部菜单 */}
-
- {links && links?.map((link, index) => )}
-
-
+
+ {/* 移动端折叠菜单 */}
+
+
+
+ collapseRef.current?.updateCollapseHeight(param)
+ }
+ />
+
+
+ {/* 导航栏菜单 */}
+
+ {/* 左侧图标Logo */}
+
+
+ {/* 折叠按钮、仅移动端显示 */}
+
+
+ {isOpen ? (
+
+ ) : (
+
+ )}
+
+
+
+ {/* 桌面端顶部菜单 */}
+
+ {links &&
+ links?.map((link, index) => (
+
+ ))}
+
+
+
)
}
diff --git a/themes/movie/components/Header.js b/themes/movie/components/Header.js
index a0f2d78c..c799d740 100644
--- a/themes/movie/components/Header.js
+++ b/themes/movie/components/Header.js
@@ -28,25 +28,25 @@ export const Header = props => {
id: 1,
icon: 'fa-solid fa-house',
name: locale.NAV.INDEX,
- to: '/',
+ href: '/',
show: siteConfig('MOVIE_MENU_INDEX', null, CONFIG)
},
{
id: 2,
icon: 'fas fa-search',
name: locale.NAV.SEARCH,
- to: '/search',
+ href: '/search',
show: siteConfig('MOVIE_MENU_SEARCH', null, CONFIG)
},
{
id: 3,
icon: 'fas fa-archive',
name: locale.NAV.ARCHIVE,
- to: '/archive',
+ href: '/archive',
show: siteConfig('MOVIE_MENU_ARCHIVE', null, CONFIG)
}
// { icon: 'fas fa-folder', name: locale.COMMON.CATEGORY, to: '/category', show: siteConfig('MENU_CATEGORY', null, CONFIG) },
// { icon: 'fas fa-tag', name: locale.COMMON.TAGS, to: '/tag', show: siteConfig('MENU_TAG', null, CONFIG) }
]
if (customNav) {
@@ -109,11 +109,18 @@ export const Header = props => {
{/* 右侧菜单 */}
<>
-
@@ -28,25 +28,25 @@ export const Header = props => {
show: siteConfig('MOVIE_MENU_ARCHIVE', null, CONFIG)
}
- // { icon: 'fas fa-folder', name: locale.COMMON.CATEGORY, to: '/category', show: siteConfig('MENU_CATEGORY', null, CONFIG) },
- // { icon: 'fas fa-tag', name: locale.COMMON.TAGS, to: '/tag', show: siteConfig('MENU_TAG', null, CONFIG) }
+ // { icon: 'fas fa-folder', name: locale.COMMON.CATEGORY, href: '/category', show: siteConfig('MENU_CATEGORY', null, CONFIG) },
+ // { icon: 'fas fa-tag', name: locale.COMMON.TAGS, href: '/tag', show: siteConfig('MENU_TAG', null, CONFIG) }
]
if (customNav) {